@@ -8,12 +8,15 @@ from pyvista.utilities.sphinx_gallery import _get_sg_image_scraper
 
 from ansys.mapdl.core._version import __version__
 from ansys.mapdl.core.convert import convert_script
-from ansys.mapdl.core.launcher import (launch_mapdl, change_default_ansys_path,
+from ansys.mapdl.core.launcher import (launch_mapdl,
+                                       change_default_ansys_path,
+                                       find_ansys,
                                        close_all_local_instances)
-from ansys.mapdl.core.misc import Report, _configure_pyvista, _check_has_ansys
+from ansys.mapdl.core.misc import Report, _check_has_ansys
 from ansys.mapdl.core.launcher import get_ansys_path
 from ansys.mapdl.core.mapdl_grpc import MapdlGrpc as Mapdl
 from ansys.mapdl.core.pool import LocalMapdlPool
+from ansys.mapdl.core.theme import MapdlTheme
 
 from ansys.mapdl.core import examples
 
@@ -37,9 +40,6 @@ try:
 except:  # pragma: no cover
     pass
 
-# set pyvista defaults
-_configure_pyvista()
-
 
 if 'ANSJUPHUB_VER' in os.environ:
     from ansys.mapdl.core.jupyter import launch_mapdl_on_cluster as launch_mapdl
