@@ -22,7 +22,7 @@ if not os.path.isdir(SETTINGS_DIR):
         os.makedirs(SETTINGS_DIR)
     except:
         warnings.warn('Unable to create settings directory.\n' +
-                      'Will be unable to cache ANSYS executable location')
+                      'Will be unable to cache MAPDL executable location')
 
 CONFIG_FILE = os.path.join(SETTINGS_DIR, 'config.txt')
 ALLOWABLE_MODES = ['corba', 'console', 'grpc']
@@ -94,6 +94,14 @@ def close_all_local_instances(port_range=None):
     port_range : list, optional
         Defaults to ``range(50000, 50200)``.  Expand this range if
         there are many potential instances of MAPDL in gRPC mode.
+
+    Examples
+    --------
+    Close all instances on in the range of 50000 and 50199.
+
+    >>> import ansys.mapdl.core as pymapdl
+    >>> pymapdl.close_all_local_instances()
+
     """
     if port_range is None:
         port_range = range(50000, 50200)
@@ -140,7 +148,7 @@ def port_in_use(port, host=LOCALHOST):
 
 def launch_grpc(exec_file='', jobname='file', nproc=2, ram=None,
                 run_location=None, port=MAPDL_DEFAULT_PORT,
-                additional_switches='', custom_bin=None,
+                additional_switches='',
                 override=True, timeout=20, verbose=False) -> tuple:
     """Start MAPDL locally in gRPC mode.
 
@@ -169,14 +177,14 @@ def launch_grpc(exec_file='', jobname='file', nproc=2, ram=None,
         port available after (or including) this port.
 
     additional_switches : str, optional
-        Additional switches for MAPDL, for example aa_r, and academic
-        research license, would be added with:
+        Additional switches for MAPDL, for example ``"-aa_r"``, and
+        academic research license, would be added with:
 
         - ``additional_switches="-aa_r"``
 
-        Avoid adding switches like -i -o or -b as these are already
-        included to start up the MAPDL server.  See the notes
-        section for additional details.
+        Avoid adding switches like ``"-i"`` ``"-o"`` or ``"-b"`` as
+        these are already included to start up the MAPDL server.  See
+        the notes section for additional details.
 
     custom_bin : str, optional
         Path to the MAPDL custom executable.
@@ -473,7 +481,7 @@ def find_ansys():
     --------
     Within Windows
 
-    >>> from ansys.mapdl.core.misc import find_ansys
+    >>> from ansys.mapdl.core.launcher import find_ansys
     >>> find_ansys()
     'C:/Program Files/ANSYS Inc/v211/ANSYS/bin/winx64/ansys211.exe', 21.1
 
@@ -611,7 +619,7 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
                  nproc=2, ram=None, mode=None, override=False,
                  loglevel='ERROR', additional_switches='',
                  start_timeout=120, port=None,
-                 custom_bin=None, cleanup_on_exit=True,
+                 cleanup_on_exit=True,
                  start_instance=True, ip=LOCALHOST,
                  clear_on_connect=True, log_apdl=False,
                  verbose_mapdl=False, **kwargs):
@@ -710,6 +718,12 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
         ``True``, giving you a fresh environment when connecting to
         MAPDL.
 
+    log_apdl : str, optional
+        Enables logging every APDL command to the local disk.  This
+        can be used to "record" all the commands that are sent to
+        MAPDL via PyMAPDL so a script can be run within MAPDL without
+        PyMAPDL.
+
     remove_temp_files : bool, optional
         Removes temporary files on exit.  Default ``False``.
 
@@ -850,14 +864,13 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
         # Load cached path
         exec_file = get_ansys_path()
         if exec_file is None:
-            raise FileNotFoundError('Invalid or path or cannot load cached '
-                                    'ansys path.  Enter one manually using '
-                                    'launch_mapdl(exec_file=)')
+            raise FileNotFoundError('Invalid exec_file path or cannot load cached '
+                                    'mapdl path.  Enter one manually by specifying '
+                                    'exec_file=')
     else:  # verify ansys exists at this location
         if not os.path.isfile(exec_file):
-            raise FileNotFoundError('Invalid ANSYS executable at "%s"\n'
-                                    % exec_file + 'Enter one manually using '
-                                    'launch_mapdl(exec_file=)')
+            raise FileNotFoundError(f'Invalid MAPDL executable at "{exec_file}"\n'
+                                    'Enter one manually using exec_file=')
 
     # verify run location
     if run_location is None:
@@ -885,23 +898,18 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
             os.environ['I_MPI_SHM_LMT'] = 'shm'
 
     # cache start parameters
+    start_parm = {'exec_file': exec_file,
+                  'run_location': run_location,
+                  'additional_switches': additional_switches,
+                  'jobname': jobname,
+                  'nproc': nproc}
+
     if mode in ['console', 'corba']:
-        start_parm = {'exec_file': exec_file,
-                      'run_location': run_location,
-                      'jobname': jobname,
-                      'nproc': nproc,
-                      'additional_switches': additional_switches,
-                      'start_timeout': start_timeout}
+        start_parm['start_timeout'] = start_timeout
     else:
-        start_parm = {'exec_file': exec_file,
-                      'jobname': jobname,
-                      'nproc': nproc,
-                      'ram': ram,
-                      'run_location': run_location,
-                      'additional_switches': additional_switches,
-                      'custom_bin': custom_bin,
-                      'override': override,
-                      'timeout': start_timeout}
+        start_parm['ram'] = ram
+        start_parm['override'] = override
+        start_parm['timeout'] = start_timeout
 
     if mode == 'console':
         from ansys.mapdl.core.mapdl_console import MapdlConsole
@@ -913,8 +921,7 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
             from ansys.mapdl.core.mapdl_corba import MapdlCorba
         except ImportError:
             raise ImportError('To use this feature, install the MAPDL CORBA package'
-                              ' with:\n\n'
-                              '    pip install ansys_corba')
+                              ' with:\n\npip install ansys_corba') from None
 
         broadcast = kwargs.get('log_broadcast', False)
         mapdl = MapdlCorba(loglevel=loglevel, log_apdl=log_apdl,
@@ -927,7 +934,7 @@ def launch_mapdl(exec_file=None, run_location=None, jobname='file',
                           cleanup_on_exit=cleanup_on_exit,
                           loglevel=loglevel, set_no_abort=set_no_abort,
                           remove_temp_files=kwargs.pop('remove_temp_files', False),
-                          **start_parm)
+                          log_apdl=log_apdl, **start_parm)
         if run_location is None:
             mapdl._path = actual_run_location
     else:
