@@ -18,8 +18,8 @@ from ansys.mapdl.core.misc import (random_string, supress_logging,
 from ansys.mapdl.core.errors import MapdlRuntimeError, MapdlInvalidRoutineError
 from ansys.mapdl.core.plotting import general_plotter
 from ansys.mapdl.core.post import PostProcessing
-from ansys.mapdl.core import commands
-from .commands import Commands
+from ansys.mapdl.core.commands import Commands
+
 
 _PERMITTED_ERRORS = [
     r'(\*\*\* ERROR \*\*\*).*(?:[\r\n]+.*)+highly distorted.',
@@ -131,7 +131,6 @@ class _MapdlCore(Commands):
 
         self._log = setup_logger(loglevel.upper())
         self._log.debug('Logging set to %s', loglevel)
-        self.non_interactive = self._non_interactive(self)
 
         from ansys.mapdl.core.parameters import Parameters
         self._parameters = Parameters(self)
@@ -145,10 +144,34 @@ class _MapdlCore(Commands):
 
         self._post = PostProcessing(self)
 
+    @property
+    def non_interactive(self):
+        """Non-interactive context manager.
+
+        Use this when using commands that require user
+        interaction within MAPDL (e.g. :func:`Mapdl.vwrite`).
+
+        Examples
+        --------
+        Use the non-interactive context manager for the VWRITE
+        command.  View the last response with :attr:`Mapdl.last_response`.
+
+        >>> with mapdl.non_interactive:
+        ...    mapdl.run("*VWRITE,LABEL(1),VALUE(1,1),VALUE(1,2),VALUE(1,3)")
+        ...    mapdl.run("(1X,A8,'   ',F10.1,'  ',F10.1,'   ',1F5.3)")
+        >>> mapdl.last_response
+
+        """
+        return self._non_interactive(self)
+
     @property
     def solution(self):
         """Solution parameters of MAPDL.
 
+        Returns
+        -------
+        :class:`ansys.mapdl.core.solution.Solution`
+
         Examples
         --------
         Check if a solution has converged.
@@ -185,7 +208,27 @@ class _MapdlCore(Commands):
 
     @property
     def chain_commands(self):
-        """Chain several mapdl commands."""
+        """Chain several mapdl commands.
+
+        Commands can be separated with ``"$"`` in MAPDL rather than
+        with a line break, so you could send multiple commands to
+        MAPDL with:
+
+        ``mapdl.run("/PREP7$K,1,1,2,3")``
+
+        This method is merely a convenience context manager to allow
+        for easy chaining of PyMAPDL commands to speed up sending
+        commands to MAPDL.
+
+        View the response from MAPDL with :attr:`Mapdl.last_response`.
+
+        Examples
+        --------
+        >>> with mapdl.chain_commands:
+            mapdl.prep7()
+            mapdl.k(1, 1, 2, 3)
+
+        """
         return self._chain_commands(self)
 
     def _chain_stored(self):
@@ -215,8 +258,11 @@ class _MapdlCore(Commands):
 
     @property
     def parameters(self):
-        """Collection of MAPDL parameters obtainable from the ``*GET``
-        command or ``GET`` command.
+        """Collection of MAPDL parameters obtainable from the ``*GET`` command or ``GET`` command.
+
+        Returns
+        -------
+        :class:`ansys.mapdl.core.parameters.Parameters`
 
         Examples
         --------
@@ -254,18 +300,7 @@ class _MapdlCore(Commands):
         return self._parameters
 
     class _non_interactive:
-        """Allows user to enter commands that need to run
-        non-interactively.
-
-        Examples
-        --------
-        To use an non-interactive command like *VWRITE, use:
-
-        >>> with ansys.non_interactive:
-                ansys.run("*VWRITE,LABEL(1),VALUE(1,1),VALUE(1,2),VALUE(1,3)")
-                ansys.run("(1X,A8,'   ',F10.1,'  ',F10.1,'   ',1F5.3)")
-
-        """
+        """Allows user to enter commands that need to run non-interactively."""
         def __init__(self, parent):
             self._parent = weakref.ref(parent)
 
@@ -354,14 +389,51 @@ class _MapdlCore(Commands):
         en = stats.find('INITIAL', st)
         mapdl_version = stats[st:en].split('CUSTOMER')[0].strip()
 
-        info =  'Product:         %s\n' % product
-        info += 'MAPDL Version:   %s\n' % mapdl_version
-        info += 'PyMAPDL Version: %s\n' % pymapdl.__version__
-        return info
+        info = [f'Product:         {product}']
+        info.append(f'MAPDL Version:   {mapdl_version}')
+        info.append(f'PyMAPDL Version: {pymapdl.__version__}\n')
+        return '\n'.join(info)
 
     @property
     def geometry(self):
-        """Geometry (CAD) information."""
+        """Geometry information.
+
+        See :class:`ansys.mapdl.core.mapdl_geometry.Geometry`
+
+        Examples
+        --------
+        Print the current status of the geometry.
+
+        >>> print(mapdl.geometry)
+        MAPDL Selected Geometry
+        Keypoints:  8
+        Lines:      12
+        Areas:      6
+        Volumes:    1
+
+        Return the number of lines.
+
+        >>> mapdl.geometry.n_line
+        12
+
+        Return the number of areas.
+
+        >>> mapdl.geometry.n_area
+        6
+
+        Select a list of keypoints.
+
+        >>> mapdl.geometry.keypoint_select([1, 5, 10])
+
+        Append to an existing selection of lines.
+
+        >>> mapdl.geometry.line_select([1, 2, 3], sel_type='A')
+
+        Reselect from the existing selection of lines.
+
+        >>> mapdl.geometry.line_select([3, 4, 5], sel_type='R')
+
+        """
         return self._geometry
 
     @property
@@ -374,6 +446,10 @@ class _MapdlCore(Commands):
     def mesh(self):
         """Mesh information.
 
+        Returns
+        -------
+        :class:`Mapdl.Mesh <ansys.mapdl.core.mesh_grpc.Mesh>`
+
         Examples
         --------
         Return an array of the active nodes
@@ -534,7 +610,31 @@ class _MapdlCore(Commands):
 
         Examples
         --------
+        >>> from ansys.mapdl.core import launch_mapdl
+        >>> mapdl = launch_mapdl()
+
+        Create a square area using keypoints
+
+        >>> mapdl.prep7()
+        >>> mapdl.k(1, 0, 0, 0)
+        >>> mapdl.k(2, 1, 0, 0)
+        >>> mapdl.k(3, 1, 1, 0)
+        >>> mapdl.k(4, 0, 1, 0)    
+        >>> mapdl.l(1, 2)
+        >>> mapdl.l(2, 3)
+        >>> mapdl.l(3, 4)
+        >>> mapdl.l(4, 1)
+        >>> mapdl.al(1, 2, 3, 4)
+
+        Open up the gui
+
         >>> mapdl.open_gui()
+
+        Resume where you left off
+
+        >>> mapdl.et(1, 'MESH200', 6)
+        >>> mapdl.amesh('all')
+        >>> mapdl.eplot()    
         """
         # lazy load here to avoid circular import
         from ansys.mapdl.core.launcher import get_ansys_path
@@ -613,6 +713,10 @@ class _MapdlCore(Commands):
 
         Displays nodes.
 
+        .. note::
+            PyMAPDL plotting commands with ``vtk=True`` ignore any
+            values set with the ``PNUM`` command.
+
         Parameters
         ----------
         knum : bool, int, optional
@@ -689,6 +793,10 @@ class _MapdlCore(Commands):
 
         APDL Command: VPLOT
 
+        .. note::
+            PyMAPDL plotting commands with ``vtk=True`` ignore any
+            values set with the ``PNUM`` command.
+
         Parameters
         ----------
         nv1, nv2, ninc
@@ -723,25 +831,29 @@ class _MapdlCore(Commands):
 
         Examples
         --------
-        Plot while displaying area numbers
+        Plot while displaying area numbers.
 
         >>> mapdl.vplot(show_area_numbering=True)
+
         """
         if vtk is None:
             vtk = self._use_vtk
 
         if vtk:
+            kwargs.setdefault('title', 'MAPDL Volume Plot')
             cm_name = '__tmp_area2__'
-            self.cm(cm_name, 'AREA')
-            self.aslv('S')  # select areas attached to active volumes
-            self.aplot(vtk=vtk, color_areas=color_areas, quality=quality,
-                       show_area_numbering=show_area_numbering,
-                       show_line_numbering=show_line_numbering,
-                       show_lines=show_lines, **kwargs)
-            self.cmsel('S', cm_name, 'AREA')
+            self.cm(cm_name, 'AREA', mute=True)
+            self.aslv('S', mute=True)  # select areas attached to active volumes
+            out = self.aplot(vtk=vtk, color_areas=color_areas, quality=quality,
+                             show_area_numbering=show_area_numbering,
+                             show_line_numbering=show_line_numbering,
+                             show_lines=show_lines, **kwargs)
+            self.cmsel('S', cm_name, 'AREA', mute=True)
+            return out
         else:
             self._enable_interactive_plotting()
-            return super().vplot(nv1=nv1, nv2=nv2, ninc=ninc, **kwargs)
+            return super().vplot(nv1=nv1, nv2=nv2, ninc=ninc,
+                                 degen=degen, scale=scale, **kwargs)
 
     def aplot(self, na1="", na2="", ninc="", degen="", scale="",
               vtk=None, quality=4, show_area_numbering=False,
@@ -752,13 +864,17 @@ class _MapdlCore(Commands):
         Displays the selected areas from ``na1`` to ``na2`` in steps
         of ``ninc``.
 
+        .. note::
+            PyMAPDL plotting commands with ``vtk=True`` ignore any
+            values set with the ``PNUM`` command.
+
         Parameters
         ----------
         na1 : int, optional
             Minimum area to display.
 
         na2 : int, optional
-            Maximum area to display
+            Maximum area to display.
 
         ninc : int, optional
             Increment between minimum and maximum area.
@@ -806,12 +922,21 @@ class _MapdlCore(Commands):
 
         >>> mapdl.aplot(show_area_numbering=True, color_areas=True)
 
+        Return the plotting instance and modify it.
+
+        >>> mapdl.aplot()
+        >>> pl = mapdl.aplot(return_plotter=True)
+        >>> pl.show_bounds()
+        >>> pl.set_background('black')
+        >>> pl.add_text('my text')
+        >>> pl.show()
 
         """
         if vtk is None:
             vtk = self._use_vtk
 
         if vtk:
+            kwargs.setdefault('show_scalar_bar', False)
             kwargs.setdefault('title', 'MAPDL Area Plot')
             kwargs.setdefault('scalar_bar_args', {'title': 'Scalar Bar Title'})
             if quality > 10:
@@ -844,11 +969,11 @@ class _MapdlCore(Commands):
             if show_lines or show_line_numbering:
                 kwargs.setdefault('line_width', 2)
                 # subselect lines belonging to the current areas
-                self.cm('__area__', 'AREA')
-                self.lsla('S')
+                self.cm('__area__', 'AREA', mute=True)
+                self.lsla('S', mute=True)
 
                 lines = self.geometry.lines
-                self.cmsel('S', '__area__', 'AREA')
+                self.cmsel('S', '__area__', 'AREA', mute=True)
 
                 if show_lines:
                     meshes.append({'mesh': lines,
@@ -857,12 +982,11 @@ class _MapdlCore(Commands):
                     labels.append({'points': lines.points[50::101],
                                    'labels': lines['entity_num']})
 
-            return general_plotter(meshes, [],
-                                   labels, **kwargs)
+            return general_plotter(meshes, [], labels, **kwargs)
 
-        else:
-            self._enable_interactive_plotting()
-            return super().aplot(na1=na1, na2=na2, ninc=ninc, **kwargs)
+        self._enable_interactive_plotting()
+        return super().aplot(na1=na1, na2=na2, ninc=ninc,
+                             degen=degen, scale=scale, **kwargs)
 
     @supress_logging
     def _enable_interactive_plotting(self, pixel_res=1600):
@@ -942,9 +1066,13 @@ class _MapdlCore(Commands):
               show_line_numbering=True,
               show_keypoint_numbering=False, color_lines=False,
               **kwargs):
-        """APDL Command: LPLOT
+        """Display the selected lines.
 
-        Displays the selected lines.
+        APDL Command: LPLOT
+
+        .. note::
+            PyMAPDL plotting commands with ``vtk=True`` ignore any
+            values set with the ``PNUM`` command.
 
         Parameters
         ----------
@@ -960,11 +1088,12 @@ class _MapdlCore(Commands):
             Display line and keypoint numbers when ``vtk=True``.
 
         show_keypoint_numbering : bool, optional
-            Number keypoints.  Only valid when show_keypoints is True
+            Number keypoints.  Only valid when ``show_keypoints=True``
 
         **kwargs
-            See ``help(pyvista.plot)`` for more keyword arguments
-            related to visualizing using ``vtk``.
+            See :meth:`ansys.mapdl.core.plotting.general_plotter` for
+            more keyword arguments applicatle when visualizing with
+            ``vtk=True``.
 
         Examples
         --------
@@ -972,8 +1101,9 @@ class _MapdlCore(Commands):
 
         Notes
         -----
-        Mesh divisions on plotted lines are controlled by the LDIV
-        option of the /PSYMB command.
+        Mesh divisions on plotted lines are controlled by the ``ldiv``
+        option of the ``psymb`` command when ``vtk=False``.
+        Otherwise, line divisions are controlled automatically.
 
         This command is valid in any processor.
         """
@@ -981,6 +1111,7 @@ class _MapdlCore(Commands):
             vtk = self._use_vtk
 
         if vtk:
+            kwargs.setdefault('show_scalar_bar', False)
             kwargs.setdefault('title', 'MAPDL Line Plot')
             if not self.geometry.n_line:
                 warnings.warn('Either no lines have been selected or there '
@@ -1011,10 +1142,14 @@ class _MapdlCore(Commands):
 
     def kplot(self, np1="", np2="", ninc="", lab="", vtk=None,
               show_keypoint_numbering=True, **kwargs):
-        """Displays the selected keypoints.
+        """Display the selected keypoints.
 
         APDL Command: KPLOT
 
+        .. note::
+            PyMAPDL plotting commands with ``vtk=True`` ignore any
+            values set with the ``PNUM`` command.
+
         Parameters
         ----------
         np1, np2, ninc
@@ -1036,6 +1171,8 @@ class _MapdlCore(Commands):
         show_keypoint_numbering : bool, optional
             Display keypoint numbers when ``vtk=True``.
 
+
+
         Notes
         -----
         This command is valid in any processor.
@@ -1068,7 +1205,12 @@ class _MapdlCore(Commands):
 
     @property
     def result(self):
-        """Binary interface to the result file using ``ansys.mapdl.reader.Result``
+        """Binary interface to the result file using :class:`ansys.mapdl.reader.rst.Result`.
+
+        Returns
+        -------
+        :class:`ansys.mapdl.reader.rst.Result`.
+            Result reader class.  See `Legacy PyMAPDL Reader <https://readerdocs.pyansys.com/>`.
 
         Examples
         --------
@@ -1083,7 +1225,7 @@ class _MapdlCore(Commands):
         Result Sets : 1
         Nodes       : 3083
         Elements    : 977
-
+        ...
         Available Results:
         EMS : Miscellaneous summable items (normally includes face pressures)
         ENF : Nodal forces
@@ -1273,20 +1415,20 @@ class _MapdlCore(Commands):
         else:
             self._log.info(self._response)
 
-    def get_float(self, *args, **kwargs):
-        raise NotImplementedError('Please use ``get_value`` instead')
-
     def get_value(self, entity="", entnum="", item1="", it1num="",
                   item2="", it2num="", **kwargs):
-        """Runs the \*GET command and returns a Python value.
+        """Runs the GET command and returns a Python value.
 
-        See ``help(mapdl.starget)`` for more details.
+        This method uses :func:`_MapdlCore.get`.
+
+        See the full MADPL command documentation at `*GET
+        <https://www.mm.bme.hu/~gyebro/files/ans_help_v182/ans_cmd/Hlp_C_GET.html>`_
 
         Parameters
         ----------
         entity
             Entity keyword. Valid keywords are NODE, ELEM, KP, LINE, AREA,
-            VOLU, PDS, etc., as shown for Entity = in the tables below.
+            VOLU, PDS, etc.
 
         entnum
             The number or label for the entity (as shown for ENTNUM = in the
@@ -1331,10 +1473,12 @@ class _MapdlCore(Commands):
 
     def get(self, par="__floatparameter__", entity="", entnum="",
             item1="", it1num="", item2="", it2num="", **kwargs):
-        """APDL Command: \*GET
+        """Retrieves a value and stores it as a scalar parameter or part of an array parameter.
 
-        Retrieves a value and stores it as a scalar parameter or part
-        of an array parameter.
+        APDL Command: \*GET
+
+        See the full MADPL command at `*GET
+        <https://www.mm.bme.hu/~gyebro/files/ans_help_v182/ans_cmd/Hlp_C_GET.html>`_
 
         Parameters
         ----------
@@ -1953,6 +2097,10 @@ class _MapdlCore(Commands):
         """Uses the VGET command to Return an array from ANSYS as a
         Python array.
 
+        See `*VGET
+        <https://www.mm.bme.hu/~gyebro/files/ans_help_v182/ans_cmd/Hlp_C_VGET_st.html>`
+        for more details.
+
         Parameters
         ----------
         entity
@@ -1960,8 +2108,7 @@ class _MapdlCore(Commands):
             AREA, VOLU, etc
 
         entnum
-            The number of the entity (as shown for ENTNUM = in the tables
-            below).
+            The number of the entity.
 
         item1
             The name of a particular item for the given entity.  Valid
@@ -2049,12 +2196,6 @@ class _MapdlCore(Commands):
         else:
             return array
 
-    def load_parameters(self):  # pragma: no cover
-        """Depreciated in favor of ``mapdl.parameters``"""
-        raise NotImplementedError('``load_parameters`` is  Depreciated.  '
-                                  '\n\nInstead, please use:\n'
-                                  '``mapdl.parameters``')
-
     def _display_plot(self, text):
         """Display the last generated plot (*.png) from MAPDL"""
         import scooby
