@@ -264,16 +264,22 @@ class MapdlGrpc(_MapdlCore):
     @property
     def mute(self):
         """Silence the response from all MAPDL functions unless
-        explicitly set to ``True``
+        explicitly set to ``True``.
+
+        Returns
+        -------
+        bool
+            Current state of the mute.
 
         Examples
         --------
         >>> mapdl.mute = True
-        >>> mapdl.prep()
+        >>> mapdl.prep7()
         ''
 
-        Override this with ``mute=False``.  This is useful for methods
-        that parse the MAPDL output like ``k``.
+        Temporarily override the instance setting this with
+        ``mute=False``.  This is useful for methods that parse the
+        MAPDL output like ``k``.
 
         >>> mapdl.k('', 1, 1, 1, mute=False)
         1
@@ -283,7 +289,6 @@ class MapdlGrpc(_MapdlCore):
 
     @mute.setter
     def mute(self, value):
-        """Set mute."""
         self._mute = value
 
     def __repr__(self):
@@ -1327,6 +1332,10 @@ class MapdlGrpc(_MapdlCore):
     def math(self):
         """APDL math interface
 
+        Returns
+        -------
+        :class:`MapdlMath <ansys.mapdl.core.math.MapdlMath>`
+
         Examples
         --------
         Get the stiffness matrix from MAPDL
@@ -1598,3 +1607,23 @@ class MapdlGrpc(_MapdlCore):
             raise FileNotFoundError('No results found at %s' % result_path)
 
         return read_binary(result_path)
+
+    @wraps(_MapdlCore.igesin)
+    def igesin(self, fname="", ext="", **kwargs):
+        """Wrap the IGESIN command to handle the remote case."""
+        if self._local:
+            out = super().igesin(fname, ext, **kwargs)
+        elif not fname:
+            out = super().igesin(**kwargs)
+        elif fname in self.list_files():
+            # check if this file is already remote
+            out = super().igesin(fname, ext, **kwargs)
+        else:
+            if not os.path.isfile(fname):
+                raise FileNotFoundError(f'Unable to find {fname}.  You may need to'
+                                        'input the full path to the file.')
+
+            basename = self.upload(fname, progress_bar=False)
+            out = super().igesin(basename, **kwargs)
+
+        return out
