@@ -1,5 +1,5 @@
 """Contains the MapdlMath classes, allowing for math operations within
-mapdl from Python.  """
+MAPDL from Python.  """
 import os
 import weakref
 import string
@@ -10,11 +10,11 @@ import numpy as np
 from ansys.grpc.mapdl import ansys_kernel_pb2 as anskernel
 from ansys.grpc.mapdl import mapdl_pb2 as pb_types
 
-from .parameters import interp_star_status
 from .errors import ANSYSDataTypeError, protect_grpc
 from .mapdl_grpc import MapdlGrpc
-from .common_grpc import (parse_chunks, ANSYS_VALUE_TYPE,
-                          DEFAULT_CHUNKSIZE, DEFAULT_FILE_CHUNK_SIZE)
+from .common_grpc import (ANSYS_VALUE_TYPE, DEFAULT_CHUNKSIZE,
+                          DEFAULT_FILE_CHUNK_SIZE)
+from .check_version import version_requires, meets_version, VersionError
 
 
 MYCTYPE = {np.int32: 'I',
@@ -59,6 +59,32 @@ def get_nparray_chunks(name, array, chunk_size=DEFAULT_FILE_CHUNK_SIZE):
                                          chunk=chunk)
         i += chunk_size
 
+def get_nparray_chunks_mat(name, array, chunk_size=DEFAULT_FILE_CHUNK_SIZE):
+    """Serializes a 2D numpy array into chunks
+
+    Uses the ``SetMatDataRequest``
+
+    """
+    stype = NP_VALUE_TYPE[array.dtype.type]
+    sh1 = array.shape[0]
+    sh2 = array.shape[1]
+    i = 0  # position counter
+    byte_array = array.tobytes(order='F')
+    while i < len(byte_array):
+        piece = byte_array[i: i + chunk_size]
+        chunk = anskernel.Chunk(payload=piece, size=len(piece))
+        yield pb_types.SetMatDataRequest(mname=name, stype=stype, nrow=sh1,
+                                         ncol=sh2, chunk=chunk)
+        i += chunk_size
+
+
+def list_allowed_dtypes():
+    """Return a list of human readable Mapdl supported datatypes"""
+    dtypes = list(NP_VALUE_TYPE.keys())
+    if None in dtypes:
+        dtypes.remove(None)
+    return '\n'.join([f'{dtype}' for dtype in dtypes])
+
 
 class MapdlMath():
     """Abstract mapdl math class.  Created from a ``Mapdl`` instance.
@@ -100,15 +126,38 @@ class MapdlMath():
         """Return the weakly referenced instance of mapdl"""
         return self._mapdl_weakref()
 
+    @property
+    def _server_version(self):
+        """Return the version of MAPDL"""
+        return self._mapdl._server_version
+
     def free(self):
-        """Delete all vectors"""
+        """Delete all vectors.
+
+        Examples
+        --------
+        >>> mm.free()
+        """
         self._mapdl.run("*FREE,ALL", mute=True)
 
     def __repr__(self):
         return self._status
 
     def status(self):
-        """Print out the status of all APDLMath Objects"""
+        """Print out the status of all APDLMath Objects.
+
+        Examples
+        --------
+        >>> mm.status()
+        APDLMATH PARAMETER STATUS-  (      4 PARAMETERS DEFINED)
+        Name         Type   Mem. (MB)       Dims            Workspace
+        NJHLVM       SMAT   0.011           [126:126]               1
+        RMAXLQ       SMAT   0.011           [126:126]               1
+        WWYLBR       SMAT   0.011           [126:126]               1
+        FIOMZR       VEC    0.001           126                     1
+
+
+        """
         print(self._status)
 
     @property
@@ -117,7 +166,7 @@ class MapdlMath():
         return self._mapdl.run("*STATUS,MATH", mute=False)
 
     def vec(self, size=0, dtype=np.double, init=None, name=None):
-        """Create a vector
+        """Create a vector.
 
         Parameters
         ----------
@@ -125,15 +174,19 @@ class MapdlMath():
             Size of the vector
 
         dtype : np.dtype, optional
-            Datatype of the vector.  Must be either np.int32, np.int64, or np.double
+            Datatype of the vector.  Must be either ``np.int32``,
+            ``np.int64``, or ``np.double``.
 
         init : str, optional
-            Initialization options.  Can be ones, zeros, or rand.
+            Initialization options.  Can be ``"ones"``, ``"zeros"``, or ``"rand"``.
+
+        name : str, optional
+            Give the vector a name.  Otherwise one will be automatically generated.
 
         Returns
         -------
         vector : ansys.mapdl.math.AnsVec
-            ANSYS Vector
+            Ansys Vector
         """
         if dtype not in MYCTYPE:
             raise ANSYSDataTypeError
@@ -157,15 +210,22 @@ class MapdlMath():
             Number of columns.
 
         dtype : np.dtype, optional
-            Datatype of the vector.  Must be either np.int32, np.int64, or np.double
+            Datatype of the vector.  Must be either ``np.int32``,
+            ``np.int64``, or ``np.double``.
 
         init : str, optional
-            Initialization options.  Can be ones, zeros, or rand.
+            Initialization options.  Can be ``"ones"``, ``"zeros"``,
+            or ``"rand"``.
+
+        name : str, optional
+            Matrix name.  If given, assigns a MAPDL matrix based on
+            the existing named matrix.  Otherwise one will be
+            automatically generated.
 
         Returns
         -------
         matrix : ansys.math.AnsMat
-            ANSYS matrix
+            ANSYS matrix.
         """
         if dtype not in MYCTYPE:
             raise ValueError('Invalid datatype.  Must be one of the following:\n' +
@@ -184,7 +244,7 @@ class MapdlMath():
             elif (init == "zeros"):
                 mat.zeros()
             elif init is not None:
-                raise ValueError("Invalid init method")
+                raise ValueError(f"Invalid init method '{init}'")
         else:
             info = self._mapdl._data_info(name)
             mtype = info.objtype
@@ -196,7 +256,7 @@ class MapdlMath():
         return mat
 
     def zeros(self, nrow, ncol=None, dtype=np.double):
-        """Create a vector or matrix containing all zeros
+        """Create a vector or matrix containing all zeros.
 
         nrow : int
             Number of rows.
@@ -205,12 +265,13 @@ class MapdlMath():
             Number of columns.  If specified, returns a matrix.
 
         dtype : np.dtype, optional
-            Datatype of the vector.  Must be either np.int32, np.int64, or np.double
+            Datatype of the vector.  Must be either ``np.int32``,
+            ``np.int64``, or ``np.double``.
 
         Returns
         -------
         ans_vec_mat : ansys.AnsVec or ansys.AnsMat
-            ANSYS vector or matrix depending on if "ncol" is specified
+            ANSYS vector or matrix depending on if ``ncol`` is specified
 
         Examples
         --------
@@ -225,9 +286,6 @@ class MapdlMath():
 
         >>> mat = mm.zeros(10, 10)
         """
-        if dtype not in MYCTYPE:
-            raise ANSYSDataTypeError
-
         if not ncol:
             return self.vec(nrow, dtype, init="zeros")
         else:
@@ -243,7 +301,8 @@ class MapdlMath():
             Number of columns.  If specified, returns a matrix.
 
         dtype : np.dtype, optional
-            Datatype of the vector.  Must be either np.int32, np.int64, or np.double
+            Datatype of the vector.  Must be either ``np.int32``,
+            ``np.int64``, or ``np.double``.
 
         Returns
         -------
@@ -263,7 +322,6 @@ class MapdlMath():
 
         >>> mat = mm.ones(10, 10)
         """
-
         if not ncol:
             return self.vec(nrow, dtype, init="ones")
         else:
@@ -279,7 +337,8 @@ class MapdlMath():
             Number of columns.  If specified, returns a matrix.
 
         dtype : np.dtype, optional
-            Datatype of the vector.  Must be either np.int32, np.int64, or np.double
+            Datatype of the vector.  Must be either ``np.int32``,
+            ``np.int64``, or ``np.double``.
 
         Returns
         -------
@@ -346,21 +405,60 @@ class MapdlMath():
             name = id_generator()
         elif not isinstance(name, str):
             raise TypeError('``name`` parameter must be a string')
-
+        
+        from scipy import sparse
         self._set_mat(name, matrix, triu)
-        return AnsSparseMat(name, self._mapdl)
+        if sparse.issparse(matrix):
+            return AnsSparseMat(name, self._mapdl)
+        else:
+            return AnsDenseMat(name, self._mapdl)
 
-    def load_matrix_from_file(self, type_=np.double, fname="file.full", matId="STIFF"):
-        """Load a matrix from a file"""
+    def load_matrix_from_file(self, dtype=np.double, fname="file.full",
+                              mat_id="STIFF"):
+        """Import a matrix from an existing FULL file.
+
+        Parameters
+        ----------
+        dtype : numpy.dtype, optional
+            Numpy data type to store the vector as.  Defaults to
+            ``np.double``.
+
+        fname : str, optional
+            Filename to read the matrix from.  Defaults to ``"file.full"``.
+
+        mat_id : str, optional
+            Matrix type.  Defaults to ``"STIFF"``
+
+            * ``"STIFF"`` - Stiffness matrix
+            * ``"MASS"`` - Mass matrix
+            * ``"DAMP"`` - Damping matrix
+            * ``"NOD2BCS"`` - Mapping vector relating the full set of
+              nodal DOFs to the subset that the solver uses
+            * ``"USR2BCS"`` - Mapping vector relating the full set of
+              external nodal DOFs to the subset that the solver uses
+            * ``"GMAT"`` - Constraint equation matrix
+            * ``"K"``_RE - Real part of the stiffness matrix
+            * ``"K"``_IM - Imaginary part of the stiffness matrix
+
+
+        """
         name = id_generator()
         self._mapdl._log.info("Calling MAPDL to extract the %s matrix from %s",
-                              matId, fname)
-        self._mapdl.run(f"*SMAT,{name},{MYCTYPE[type_]},IMPORT,FULL,{fname},{matId}",
+                              mat_id, fname)
+        self._mapdl.run(f"*SMAT,{name},{MYCTYPE[dtype]},IMPORT,FULL,{fname},{mat_id}",
                         mute=True)
         return AnsSparseMat(name, self._mapdl)
 
     def stiff(self, dtype=np.double, fname="file.full"):
-        """Load the stiffness matrix from the full file
+        """Load the stiffness matrix from a full file.
+
+        Parameters
+        ----------
+        dtype : numpy.dtype, optional
+            Numpy data type to store the vector as.  Defaults to ``np.double``
+
+        fname : str, optional
+            Filename to read the matrix from.
 
         Examples
         --------
@@ -377,7 +475,15 @@ class MapdlMath():
         return self.load_matrix_from_file(dtype, fname, "STIFF")
 
     def mass(self, dtype=np.double, fname="file.full"):
-        """Load the mass matrix from the full file
+        """Load the mass matrix from a full file.
+
+        Parameters
+        ----------
+        dtype : numpy.dtype, optional
+            Numpy data type to store the vector as.  Defaults to ``np.double``
+
+        fname : str, optional
+            Filename to read the matrix from.
 
         Examples
         --------
@@ -395,31 +501,85 @@ class MapdlMath():
         return self.load_matrix_from_file(dtype, fname, "MASS")
 
     def damp(self, dtype=np.double, fname="file.full"):
-        """Load the damping matrix from the full file"""
+        """Load the damping matrix from the full file
+
+        Parameters
+        ----------
+        dtype : numpy.dtype, optional
+            Numpy data type to store the vector as.  Defaults to ``np.double``
+
+        fname : str, optional
+            Filename to read the matrix from.
+
+        Examples
+        --------
+        >>> m = mapdl.math.damp()
+        >>> m
+        APDLMATH Matrix 60 x 60
+
+        Convert to a scipy array
+
+        >>> mat = m.asarray()
+        >>> mat
+        <60x60 sparse matrix of type '<class 'numpy.float64'>'
+            with 1734 stored elements in Compressed Sparse Row format>
+
+        """
         return self.load_matrix_from_file(dtype, fname, "DAMP")
 
-    def getVec(self, dtype=np.double, fname="file.full", matId="RHS"):
-        """Load a vector from a file"""
+    def get_vec(self, dtype=np.double, fname="file.full", mat_id="RHS"):
+        """Load a vector from a file.
+
+        Parameters
+        ----------
+        dtype : numpy.dtype, optional
+            Numpy data type to store the vector as.  Defaults to ``np.double``
+
+        fname : str, optional
+            Filename to read the vector from.
+
+        mat_id : str, optional
+            Vector ID to load.  If loading from a ``"*.full"`` file,
+            can be one of the following:
+
+            * ``"RHS"`` - Load vector
+            * ``"GVEC"`` - Constraint equation constant terms
+            * ``"BACK"`` - nodal mapping vector (internal to user)
+            * ``"FORWARD"`` - nodal mapping vector (user to internal)
+
+        Returns
+        --------
+        ansys.mapdl.math.AnsVec
+            APDL vector instance generated from the file.
+
+        Examples
+        --------
+        >>> b = mm.get_vec(fname='PRSMEMB.full', mat_id="RHS")
+        >>> b
+        APDLMath Vector Size 126
+
+        """
         name = id_generator()
         self._mapdl._log.info("Call MAPDL to extract the %s vector from the file %s",
-                              matId, fname)
-        self._mapdl.run(f"*VEC,{name},{MYCTYPE[dtype]},IMPORT,FULL,{fname},{matId}",
+                              mat_id, fname)
+        self._mapdl.run(f"*VEC,{name},{MYCTYPE[dtype]},IMPORT,FULL,{fname},{mat_id}",
                         mute=True)
         return AnsVec(name, self._mapdl)
 
-    def set_vec(self, vname, data):
+    def set_vec(self, data, name=None):
         """Push a numpy array or Python list to the MAPDL Memory
         Workspace.
 
         Parameters
         ----------
-        vname : str
-            APDLMath vector name
-
         data : np.ndarray, list
             Numpy array or Python list to push to MAPDL.  Must be 1
             dimensional.
 
+        vname : str, optional
+            APDLMath vector name.  If unset, one will be automatically
+            generated.
+
         Returns
         -------
         vec : ansys.mapdl.math.AnsVec
@@ -428,19 +588,126 @@ class MapdlMath():
         Examples
         --------
         >>> data = np.random.random(10)
-        >>> vec = mm.set_vec('NewVec', data)
+        >>> vec = mm.set_vec(data)
         >>> np.isclose(vec.asarray(), data)
         True
         """
-        self._set_vec(vname, data)
-        return AnsVec(vname, self._mapdl)
+        if name is None:
+            name = id_generator()
+        self._set_vec(name, data)
+        return AnsVec(name, self._mapdl)
 
-    def rhs(self, type_=np.double, fname="file.full"):
-        return self.getVec(type_, fname, "RHS")
+    def rhs(self, dtype=np.double, fname="file.full"):
+        """Return the load vector from a full file.
+
+        Parameters
+        ----------
+        dtype : numpy.dtype, optional
+            Data type to store the vector as.  Defaults to ``np.double``.
+
+        fname : str, optional
+            Filename to read the vector from.  Defaults to ``"file.full"``.
+
+        Returns
+        -------
+        ansys.mapdl.math.AnsVec
+            APDL vector instance generated from the file.
+
+        Examples
+        --------
+        >>> rhs = mm.rhs(fname='PRSMEMB.full')
+        APDLMath Vector Size 126
+
+        """
+        return self.get_vec(dtype, fname, "RHS")
+
+    def svd(self, mat, thresh='', sig='', v='', **kwargs):
+        """Apply an SVD Algorithm on a matrix.
+
+        The SVD algorithm is only applicable to dense matrices. 
+        Columns that are linearly dependent on others are removed,
+        leaving the independent or basis vectors. The matrix is
+        resized according to the new size determined by the algorithm.
+
+        For the SVD algorithm, the singular value decomposition of an
+        input matrix is a factorization of the form:
+
+        ``M = U*SIGMA*V.T``
+
+        For more details, see:
+        https://en.wikipedia.org/wiki/Singular_value_decomposition
+
+        Parameters
+        ----------
+        mat : ansys.AnsMat
+            The array to compress.
+
+        thresh : float, optional
+            Numerical threshold value used to manage the compression.
+            Default is 1E-7.
+
+        sig : str, optional
+            Name of the vector used to store the ``SIGMA`` values.
+
+        v : str, optional
+            Name of the vector used to store the values from ``v``.
+            See the equation above.
+
+        Examples
+        --------
+        Apply SVD on an existing Dense Rectangular Matrix, using
+        default threshold.  The matrix is modified in-place.
+
+        >>> mm.svd(mat)
+        """
+        kwargs.setdefault('mute', True)
+        self._mapdl.run(f"*COMP,{mat.id},SVD,{thresh},{sig},{v}", **kwargs)
+
+    def mgs(self, mat, thresh='', **kwargs):
+        """Apply Modified Gram-Schmidt algorithm to a matrix.
+
+        The MGS algorithm is only applicable to dense
+        matrices. Columns that are linearly dependent on others are
+        removed, leaving the independent or basis vectors. The matrix
+        is resized according to the new size determined by the
+        algorithm.
+
+        Parameters
+        ----------
+        mat : ansys.mapdl.core.math.AnsMat
+            The array to apply Modified Gram-Schmidt algorithm to.
+
+        thresh : float, optional
+            Numerical threshold value used to manage the compression.
+            The default value is 1E-14 for MGS.
+
+        Examples
+        --------
+        Apply MGS on an existing Dense Rectangular Matrix, using
+        default threshold.  The mat matrix is modified in-situ.
+
+        >>> mm.mgs(mat)
+        """
+        kwargs.setdefault('mute', True)
+        self._mapdl.run(f"*COMP,{mat.id},MGS,{thresh}", **kwargs)
+
+    def sparse(self, mat, thresh='', **kwargs):
+        """Sparsify a existing matrix based on a threshold value.
+
+        Parameters
+        ----------
+        mat : ansys.mapdl.core.math.AnsMat
+            The dense matrix to convert to a sparse matrix.
+        thresh : float, optional
+            Numerical threshold value used to sparsify. The default
+            value is 1E-16.
+        """
+        kwargs.setdefault('mute', True)
+        self._mapdl.run(f"*COMP,{M.id},SPARSE,{thresh}", **kwargs)
 
     def eigs(self, nev, k, m=None, c=None, phi=None, algo=None,
              fmin=None, fmax=None):
-        """Solve an eigenproblem
+        """Solve an eigenproblem.
 
         Parameters
         ----------
@@ -531,15 +798,15 @@ class MapdlMath():
 
         Returns
         -------
-        objout : ansys.mapdl.math.AnsVec or ansys.mapdl.math.AnsMat
-            Sum of the two input objects.  Type of the output matches type of the input.
-            Sum of the two vectors/matrices.
+        ansys.mapdl.math.AnsVec or ansys.mapdl.math.AnsMat
+            Sum of the two input objects.  Type of the output matches
+            type of the input.  Sum of the two vectors/matrices.
 
         Examples
         --------
         >>> v = mm.ones(10)
         >>> w = mm.ones(10)
-        >>> x = mm.add( v, w)
+        >>> x = mm.add(v, w)
         """
         return obj1 + obj2
 
@@ -556,7 +823,7 @@ class MapdlMath():
 
         Returns
         -------
-        objout : ansys.mapdl.math.AnsVec or ansys.mapdl.math.AnsMat
+        ansys.mapdl.math.AnsVec or ansys.mapdl.math.AnsMat
             Difference of the two input vectors or matrices.  Type of the output
             matches the type of the input.
 
@@ -568,14 +835,13 @@ class MapdlMath():
         """
         return obj1 - obj2
 
-    
     def factorize(self, mat):
         """Factorize a matrix
 
         Parameters
         ----------
         mat : ansys.mapdl.math.AnsMat
-            A ansys.mapdl.math matrix
+            An ansys.mapdl.math matrix.
 
         Examples
         --------
@@ -590,22 +856,30 @@ class MapdlMath():
         solver.factorize(mat)
         return solver
 
-    def norm(self, obj, ord_="nrm2"):
-        """ Matrix or vector norm
+    def norm(self, obj, order="nrm2"):
+        """Matrix or vector norm.
 
         Parameters
         ----------
         obj : ansys.mapdl.math.AnsMat or ansys.mapdl.math.AnsVec
-        ord\_ : Order of the norm. nrm2(default), nrminf, nrm1
+            ApdlMath object to compute the norm from.
+
+        order : str
+            Mathematical norm to use.  One of:
+
+            * ``'NRM2'``: L2 (Euclidean or SRSS) norm (default).
+            * ``'NRM1'``: L1 (absolute sum) norm (vectors only).
+            * ``'NRMINF'`` Maximum norm.
+
+        nrm : float
+            Norm of the matrix or vector(s).
 
         Examples
         --------
-        >>> mm = mapdl.math
-        >>> dim = 1000
-        >>> m2 = mm.rand(dim, dim)
-        >>> nrm = mm.norm( m2)
+        v = mm.ones(10)
+        3.1622776601683795
         """
-        obj.norm()
+        return obj.norm()
 
     @protect_grpc
     def _set_vec(self, vname, arr, dtype=None, chunk_size=DEFAULT_CHUNKSIZE):
@@ -636,29 +910,28 @@ class MapdlMath():
             if arr.dtype != dtype:
                 arr = arr.astype(dtype)
 
-        if arr.dtype not in list(NP_VALUE_TYPE.keys()):
-            dtypes = list(NP_VALUE_TYPE.keys())
-            if None in dtypes:
-                dtypes.remove(None)
-            raise TypeError('Invalid array datatype.  Must be one of the following:\n'
-                            + ('\n'.join([str(dtype) for dtype in dtypes])))
+        if arr.dtype not in list(MYCTYPE.keys()):
+            raise TypeError(f'Invalid array datatype {arr.dtype}\n'
+                            f'Must be one of the following:\n'
+                            f'{list_allowed_dtypes()}')
+
         chunks_generator = get_nparray_chunks(vname, arr, chunk_size)
         self._mapdl._stub.SetVecData(chunks_generator)
 
     @protect_grpc
-    def _set_mat(self, mname, arr, sym, dtype=None, chunk_size=DEFAULT_CHUNKSIZE):
-        """Transfer a scipy array to MAPDL as a MAPDL Math matrix
+    def _set_mat(self, mname, arr, sym=None, dtype=None, chunk_size=DEFAULT_CHUNKSIZE):
+        """Transfer a 2D dense or sparse scipy array to MAPDL as a MAPDL Math matrix.
 
         Parameters
         ----------
         mname : str
             Matrix parameter name.  Character ":" is not allowed.
 
-        arr : 
-            SciPy array to upload
+        arr : np.ndarray or scipy.sparse matrix
+            Matrix to upload
 
         sym : bool
-            ``True`` when sparse matrix is symmetric.
+            ``True`` when matrix is symmetric. Unused if Matrix is dense.
 
         dtype : np.dtype, optional
             Type to upload array as.  Defaults to the current array type.
@@ -667,6 +940,8 @@ class MapdlMath():
             Chunk size in bytes.  Must be less than 4MB.
 
         """
+        from scipy import sparse
+
         if ':' in mname:
             raise ValueError('The character ":" is not permitted in a MAPDL MATH'
                              ' matrix parameter name')
@@ -678,61 +953,80 @@ class MapdlMath():
                 raise ValueError('Input appears to be an array.  '
                                  'Use ``set_vec`` instead.)')
             if arr.ndim > 2:
-                raise ValueError('Dense arrays must be 2 dimensional')
+                raise ValueError('Arrays must be 2 dimensional')
 
-            from scipy import sparse
-            arr = sparse.csr_matrix(arr)
+        if sparse.issparse(arr):
+            self._send_sparse(mname, arr, sym, dtype, chunk_size)
+        else:  # must be dense matrix
+            self._send_dense(mname, arr, dtype, chunk_size)
+
+    @version_requires((0, 4, 0))
+    def _send_dense(self, mname, arr, dtype, chunk_size):
+        """Send a dense numpy array/matrix to MAPDL."""
+        if dtype is not None:
+            if arr.dtype != dtype:
+                arr = arr.astype(dtype)
+
+        if arr.dtype not in list(NP_VALUE_TYPE.keys()):
+            raise TypeError(f'Invalid array datatype {arr.dtype}\n'
+                            f'Must be one of the following:\n'
+                            f'{list_allowed_dtypes()}')
+
+        chunks_generator = get_nparray_chunks_mat(mname, arr, chunk_size)
+        self._mapdl._stub.SetMatData(chunks_generator)
+
+    def _send_sparse(self, mname, arr, sym, dtype, chunk_size):
+        """Send a scipy sparse sparse matrix to MAPDL."""
+        if sym is None:
+            raise ValueError('The symmetric flag ``sym`` must be set for a sparse '
+                             'matrix')
+        from scipy import sparse
+        arr = sparse.csr_matrix(arr)
+
+        if arr.shape[0] != arr.shape[1]:
+            raise ValueError('APDLMath only supports square matrices')
 
         if dtype is not None:
             if arr.data.dtype != dtype:
                 arr.data = arr.data.astype(dtype)
 
-        if arr.data.dtype not in list(NP_VALUE_TYPE.keys()):
-            dtypes = list(NP_VALUE_TYPE.keys())
-            if None in dtypes:
-                dtypes.remove(None)
-            raise TypeError('Invalid array datatype.  Must be one of the following:\n'
-                            + ('\n'.join([str(dtype) for dtype in dtypes])))
+        if arr.dtype not in list(NP_VALUE_TYPE.keys()):
+            raise TypeError(f'Invalid array datatype {arr.dtype}\n'
+                            f'Must be one of the following:\n'
+                            f'{list_allowed_dtypes()}')
 
-        if arr.shape[0] != arr.shape[1]:
-            raise ValueError('APDLMath only supports square matrices')
-
-        # The data vector
+        # data vector
         dataname = f'{mname}_DATA'
-        self.set_vec(dataname, arr.data)
+        self.set_vec(arr.data, dataname)
 
         # indptr vector
         indptrname = f'{mname}_IND'
-        indv = arr.indptr.astype('int64') + 1
-        self.set_vec(indptrname, indv)
+        indv = arr.indptr.astype('int64') + 1  # FORTRAN indexing
+        self.set_vec(indv, indptrname)
 
         # indices vector
         indxname = f'{mname}_PTR'
-        idx = arr.indices + 1
-        self.set_vec(indxname, idx)
+        idx = arr.indices + 1  # FORTRAN indexing
+        self.set_vec(idx, indxname)
 
-        flagsym = 'FALSE'
-        if sym is True:
-            flagsym = 'TRUE'
-
-        self._mapdl.run(f'*SMAT,{mname},D,ALLOC,CSR,{indptrname},{indxname},{dataname},{flagsym}', mute=True)
+        flagsym = 'TRUE' if sym else 'FALSE'
+        self._mapdl.run(f'*SMAT,{mname},D,ALLOC,CSR,{indptrname},{indxname},'
+                        f'{dataname},{flagsym}')
 
 
 class ApdlMathObj:
-    def __init__(self, id_, mapdl, type_=ObjType.GEN):
+    """Common class for MAPDL Math objects"""
+
+    def __init__(self, id_, mapdl, dtype=ObjType.GEN):
         self.id = id_
         self._mapdl = mapdl
-        self.type = type_
-
-    #def __del__(self):
-    #    self._mapdl._log.debug("Deleting the MAPDL Vector Object")
-    #    self._mapdl.run("*FREE," + self.id)
+        self.type = dtype
 
     def __repr__(self):
-        return "APDLMath Object %s" % str(self.id)
+        return f"APDLMath Object {self.id}"
 
     def __str__(self):
-        return self._mapdl.run("*PRINT," + self.id, mute=False)
+        return self._mapdl.run(f"*PRINT,{self.id}", mute=False)
 
     def copy(self):
         """Returns the name of the copy of this object"""
@@ -744,10 +1038,10 @@ class ApdlMathObj:
         elif self.type == ObjType.SMAT:
             acmd = "*SMAT"
         else:
-            raise TypeError("Unknown obj type: operation aborted")
+            raise TypeError(f"Copy aborted: Unknown obj type {self.type}")
 
         # APDLMath cmd to COPY vin to vout
-        self._mapdl.run(acmd + "," + name + ",D,COPY," + self.id, mute=True)
+        self._mapdl.run(f"{acmd},{name},D,COPY,{self.id}", mute=True)
         return name
 
     def _init(self, method):
@@ -799,18 +1093,25 @@ class ApdlMathObj:
 
     def axpy(self, op, val1, val2):
         """Perform the matrix operation: ``M2= v*M1 + w*M2``"""
-        cmd = "*AXPY," + str(val1) + ",0," + op.id + "," + str(val2) + ",0," + self.id
-        self._mapdl._log.info(">> Call Mapdl to perform AXPY operation")
-        self._mapdl.run(cmd, mute=True)
+        if not hasattr(op, 'id'):
+            raise TypeError('Must be an ApdlMathObj')
+        self._mapdl._log.info("Call Mapdl to perform AXPY operation")
+        self._mapdl.run(f"*AXPY,{val1},0,{op.id},{val2},0,{self.id}", mute=True)
         return self
 
     def __add__(self, op2):
+        if not hasattr(op2, 'id'):
+            raise TypeError('Must be an ApdlMathObj')
+
         opout = self.copy()
-        self._mapdl._log.info(">> Call Mapdl to perform AXPY operation")
+        self._mapdl._log.info("Call Mapdl to perform AXPY operation")
         self._mapdl.run(f"*AXPY,1,0,{op2.id},1,0,{opout.id}", mute=True)
         return opout
 
     def __sub__(self, op2):
+        if not hasattr(op2, 'id'):
+            raise TypeError('Must be an ApdlMathObj')
+
         opout = self.copy()
         self._mapdl._log.info("Call Mapdl to perform AXPY operation")
         self._mapdl.run(f"*AXPY,-1,0,{op2.id},1,0,{opout.id}", mute=True)
@@ -844,25 +1145,30 @@ class ApdlMathObj:
 
 class AnsVec(ApdlMathObj):
     """APDLMath Vector Object"""
+
     def __init__(self, id_, mapdl, dtype=np.double, init=None):
         ApdlMathObj.__init__(self, id_, mapdl, ObjType.VEC)
 
         if init not in ['ones', 'zeros', 'rand', None]:
-            raise ValueError('Invalid init option.  Should be "ones", "zeros", "rand", or None')
+            raise ValueError(f'Invalid init option {init}.\n'
+                             'Should be "ones", "zeros", "rand", or None')
 
-        if (init == "rand"):
+        if init == "rand":
             self.rand()
-        elif (init == "ones"):
+        elif init == "ones":
             self.ones()
-        elif (init == "zeros"):
+        elif init == "zeros":
             self.zeros()
 
     @property
     def size(self):
-        return int(self._mapdl.scalar_param(self.id + "_DIM"))
+        sz = self._mapdl.scalar_param(f"{self.id}_DIM")
+        if sz is None:
+            raise RuntimeError('This vector has been deleted within MAPDL.')
+        return int(sz)
 
     def __repr__(self):
-        return "APDLMath Vector Size %s" % self.size
+        return f"APDLMath Vector Size {self.size}"
 
     def __getitem__(self, num):
         if num < 0:
@@ -870,10 +1176,45 @@ class AnsVec(ApdlMathObj):
         self._mapdl.run(f"pyval={self.id}({num+1})", mute=True)
         return self._mapdl.scalar_param("pyval")
 
-    def __mul__(self, vec2):
-        raise AttributeError('Array multiplication is not yet available.  '
-                             'For dot product, please use `dot()`')
+    def __mul__(self, vec):
+        """Element-Wise product with another Ansys vector object.
 
+        Also known as Hadamard product.
+
+        .. note::
+            Requires at least MAPDL version 2021R2.
+
+        Parameters
+        ----------
+        vec : ansys.mapdl.math.AnsVec
+            Ansys vector object.
+
+        Returns
+        -------
+        ansys.mapdl.math.AnsVec
+            Hadamard product between this vector and the other vector.
+        """
+        if not meets_version(self._mapdl._server_version, (0, 4, 0)):
+            raise VersionError(f'``{func.__name__}`` requires MAPDL version 2021R2')
+
+        if not isinstance(vec, AnsVec):
+            raise TypeError('Must be an Ansys vector object')
+            
+        name = id_generator()  # internal name of the new vector/matrix
+        info = self._mapdl._data_info(self.id)
+        dtype = ANSYS_VALUE_TYPE[info.stype]
+
+        # check size consistency
+        if self.size != vec.size:
+            raise ValueError('Vectors have inconsistent sizes')
+
+        self._mapdl.run(f"*VEC,{name},{MYCTYPE[dtype]},ALLOC,{info.size1}")
+        objout = AnsVec(name, self._mapdl)
+
+        # perform the Hadamard product
+        self._mapdl.run(f"*HPROD,{self.id},{vec.id},{name}")
+        return objout
+        
     def copy(self):
         """Return a copy of this vector"""
         return AnsVec(ApdlMathObj.copy(self), self._mapdl)
@@ -957,15 +1298,12 @@ class AnsMat(ApdlMathObj):
         """
         return self._mapdl._mat_data(self.id)
 
-    def __repr__(self):
-        return f"APDLMath Matrix {self.nrow} x {self.ncol}"
-
     def __mul__(self, vec):
         raise AttributeError('Array multiplication is not yet available.  '
                              'For dot product, please use `dot()`')
 
     def dot(self, obj):
-        """Perform the matrix multiplication by another vector or matrix
+        """Perform the matrix multiplication by another vector or matrix.
 
         Parameters
         ----------
@@ -1066,11 +1404,47 @@ class AnsSparseMat(AnsMat):
         return f'Sparse APDLMath Matrix ({self.nrow}, {self.ncol})'
 
     def copy(self):
-        """Return a copy of this matrix"""
+        """Return a copy of this matrix.
+
+        Matrix remains in MAPDL.
+
+        Examples
+        --------
+        >>> k
+        Sparse APDLMath Matrix (126, 126)
+
+        >>> kcopy = k.copy()
+        >>> kcopy
+        Sparse APDLMath Matrix (126, 126)
+
+        """
         return AnsSparseMat(ApdlMathObj.copy(self), self._mapdl)
 
     def todense(self):
-        """Return this array as a dense np.ndarray"""
+        """Return this array as a dense np.ndarray
+
+        Examples
+        --------
+        >>> k
+        Sparse APDLMath Matrix (126, 126)
+
+        >>> mat = k.todense()
+        >>> mat
+        matrix([[ 2.02925393e-01,  3.78142616e-03,  0.00000000e+00, ...,
+                  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+                [ 0.00000000e+00,  2.00906608e-01,  0.00000000e+00, ...,
+                  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+                [ 0.00000000e+00,  0.00000000e+00,  2.29396542e+03, ...,
+                  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+                ...,
+                [ 0.00000000e+00,  0.00000000e+00,  0.00000000e+00, ...,
+                  2.26431549e+03, -9.11391851e-08,  0.00000000e+00],
+                [ 0.00000000e+00,  0.00000000e+00,  0.00000000e+00, ...,
+                  0.00000000e+00,  3.32179197e+03,  0.00000000e+00],
+                [ 0.00000000e+00,  0.00000000e+00,  0.00000000e+00, ...,
+                  0.00000000e+00,  0.00000000e+00,  2.48282229e-01]])
+
+        """
         return self.asarray().todense()
 
     def __array__(self):
@@ -1080,58 +1454,92 @@ class AnsSparseMat(AnsMat):
 
 class AnsSolver(ApdlMathObj):
     """APDLMath Solver Class"""
+
     def __repr__(self):
         return "APDLMath Linear Solver"
 
-    # def __del__(self):
-    #     self._mapdl._log.debug("Deleting the MAPDL Solver Object")
-    #     self._mapdl.run(f"*FREE,{self.id}")
-
-    def factorize(self, M, Algo=None):
+    def factorize(self, mat, algo=None):
         """Factorize a matrix
 
-        Performs the numerical factorization of a linear solver system.
+        Perform the numerical factorization of a linear solver system.
 
         Parameters
         ----------
+        mat : ansys.mapdl.math.AnsMat
+            An ansys.mapdl.math matrix.
+
+        algo : str, optional
+            Factorization algorithm.  Either ``"LAPACK"`` or
+            ``"DSP"``.
+
         """
-        if not Algo:
-            if (M.type == ObjType.DMAT):
-                Algo = "LAPACK"
-            elif (M.type == ObjType.SMAT):
-                Algo = "DSP"
-        self._mapdl.run(f"*LSENGINE,{Algo},{self.id},{M.id}", mute=True)
-        self._mapdl._log.info(f"Factorizing using the {Algo} package")
+        if not algo:
+            if mat.type == ObjType.DMAT:
+                algo = "LAPACK"
+            elif mat.type == ObjType.SMAT:
+                algo = "DSP"
+        self._mapdl.run(f"*LSENGINE,{algo},{self.id},{mat.id}", mute=True)
+        self._mapdl._log.info(f"Factorizing using the {algo} package")
         self._mapdl.run(f"*LSFACTOR,{self.id}", mute=True)
 
-    def solve(self, B, X=None):
-        if not X:
-            X = B.copy()
+    def solve(self, b, x=None):
+        """Solve a linear system
+
+        Parameters
+        ----------
+        b : ansys.mapdl.math.AnsVec
+            APDLmath vector.
+
+        x : ansys.mapdl.math.AnsVec, optional
+            APDLmath vector to place the solution.
+
+        Returns
+        -------
+        ansys.mapdl.math.AnsVec
+            Solution vector.  Identical to ``x`` if supplied.
+
+        Examples
+        --------
+        >>> k = mm.stiff(fname='PRSMEMB.full')
+        >>> s = mm.factorize(k)
+        >>> b = mm.get_vec(fname='PRSMEMB.full', mat_id="RHS")
+        >>> x = s.solve(b)
+        >>> x
+        APDLMath Vector Size 20000
+
+        """
+        if not x:
+            x = b.copy()
         self._mapdl._log.info("Solving")
-        self._mapdl.run(f"*LSBAC,{self.id},{B.id},{X.id}", mute=True)
-        return X
+        self._mapdl.run(f"*LSBAC,{self.id},{b.id},{x.id}", mute=True)
+        return x
 
 
 def rand(obj):
-    """Set all values of a mapdl math object to random values
+    """Set all values of a mapdl math object to random values.
 
     Parameters
     ----------
     obj : ansys.math.MapdlMath object
         MapdlMath object
+
+    Examples
+    --------
+    >>> vec = mm.ones(10)
+    >>> mm.rand(vec)
     """
     obj._mapdl.run(f"*INIT,{obj.id},RAND", mute=True)
 
 
-def solve(Mat, B, X=None, Algo=None):
-    Solver = AnsSolver(id_generator(), Mat._mapdl)
-    Solver.factorize(Mat, Algo)
-    if not X:
-        X = B.copy()
-    X = Solver.solve(B, X)
+def solve(mat, b, x=None, algo=None):
+    solver = AnsSolver(id_generator(), mat._mapdl)
+    solver.factorize(mat, algo)
+    if not x:
+        x = b.copy()
+    x = solver.solve(b, x)
 
-    del Solver
-    return X
+    del solver
+    return x
 
 
 def dot(vec1, vec2):
@@ -1150,49 +1558,9 @@ def dot(vec1, vec2):
         Dot product between the two vectors
 
     """
-    if (vec1.type != ObjType.VEC or vec2.type != ObjType.VEC):
+    if vec1.type != ObjType.VEC or vec2.type != ObjType.VEC:
         raise TypeError("Both objects must be ANSYS vectors")
 
     mapdl = vec1._mapdl
     mapdl.run(f"*DOT,{vec1.id},{vec2.id},py_val", mute=True)
     return mapdl.scalar_param("py_val")
-
-
-def interp_star_status(status, ignore_hidden=True):
-    """Interprets STATUS command output from MAPDL
-
-    Parameters
-    ----------
-    status : str
-        Output from APDL *STATUS
-
-    Returns
-    -------
-    parameters : dict
-        Dictionary of parameters.
-    """
-    parameters = {}
-    header = 'Name                   Type            '
-    for line in status.splitlines():
-        if header in line:
-            continue
-
-        try:
-            name, mtype, size_mbytes, dim, workspace = line.split()
-        except:
-            continue
-
-        if ignore_hidden:
-            if name[-5:] == '_DATA':
-                continue
-            elif name[-4:] == '_IND':
-                continue
-            elif name[-4:] == '_PTR':
-                continue
-
-        parameters[name] = {'type': mtype,
-                            'size mb': size_mbytes,
-                            'dim': dim,
-                            'workspace': workspace}
-
-    return parameters
